summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/connectiondialog.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/connectiondialog.ui.h')
-rw-r--r--kdevdesigner/designer/connectiondialog.ui.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kdevdesigner/designer/connectiondialog.ui.h b/kdevdesigner/designer/connectiondialog.ui.h
index f8df4230..4969c8fd 100644
--- a/kdevdesigner/designer/connectiondialog.ui.h
+++ b/kdevdesigner/designer/connectiondialog.ui.h
@@ -1,7 +1,7 @@
/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename slots use Qt Designer which will
** update this file, preserving your code. Create an init() slot in place of
** a constructor, and a destroy() slot in place of a destructor.
*****************************************************************************/
@@ -81,7 +81,7 @@ void ConnectionDialog::init()
}
TQValueList<MetaDataBase::Connection> conns =
- MetaDataBase::connections( MainWindow::self->formWindow() );
+ MetaDataBase::connections( TQT_TQOBJECT(MainWindow::self->formWindow()) );
for ( TQValueList<MetaDataBase::Connection>::Iterator it = conns.begin();
it != conns.end(); ++it ) {
ConnectionContainer *c = addConnection( (*it).sender, (*it).receiver,
@@ -96,7 +96,7 @@ void ConnectionDialog::init()
void ConnectionDialog::addConnection()
{
- addConnection( defaultSender, defaultReceiver, TQString::null, TQString::null );
+ addConnection( defaultSender, defaultReceiver, TQString(), TQString() );
ensureConnectionVisible();
}
@@ -147,14 +147,14 @@ ConnectionContainer *ConnectionDialog::addConnection( TQObject *sender, TQObject
connect( re, TQT_SIGNAL( currentReceiverChanged( TQObject * ) ),
this, TQT_SLOT( updateEditSlotsButton() ) );
- ConnectionContainer *c = new ConnectionContainer( this, se, si, re, sl, row );
+ ConnectionContainer *c = new ConnectionContainer( TQT_TQOBJECT(this), se, si, re, sl, row );
connections.append( c );
connect( c, TQT_SIGNAL( changed( ConnectionContainer * ) ),
this, TQT_SLOT( updateConnectionState( ConnectionContainer * ) ) );
connectionsTable->setCurrentCell( row, 0 );
- connectionsTable->verticalHeader()->setLabel( row, *invalidConnection, TQString::null );
+ connectionsTable->verticalHeader()->setLabel( row, *invalidConnection, TQString() );
if ( sender )
se->setSenderEx( sender );
@@ -175,20 +175,20 @@ ConnectionContainer *ConnectionDialog::addConnection( TQObject *sender, TQObject
void ConnectionDialog::updateConnectionState( ConnectionContainer *c )
{
- c->repaint();
+ c->tqrepaint();
if ( c->isValid() )
connectionsTable->verticalHeader()->setLabel( c->row(),
- *validConnection, TQString::null );
+ *validConnection, TQString() );
else
connectionsTable->verticalHeader()->setLabel( c->row(),
- *invalidConnection, TQString::null );
+ *invalidConnection, TQString() );
}
void ConnectionDialog::okClicked()
{
TQValueList<MetaDataBase::Connection> oldConnections =
- MetaDataBase::connections( MainWindow::self->formWindow() );
+ MetaDataBase::connections( TQT_TQOBJECT(MainWindow::self->formWindow()) );
TQPtrList<Command> newConnectionCmds;
TQPtrList<Command> oldConnectionCmds;
for ( ConnectionContainer *c = connections.first(); c; c = connections.next() ) {
@@ -215,7 +215,7 @@ void ConnectionDialog::okClicked()
TQValueList<MetaDataBase::Connection> conns =
- MetaDataBase::connections( MainWindow::self->formWindow() );
+ MetaDataBase::connections( TQT_TQOBJECT(MainWindow::self->formWindow()) );
for ( TQValueList<MetaDataBase::Connection>::Iterator it = conns.begin();
it != conns.end(); ++it ) {
RemoveConnectionCommand *cmd = new RemoveConnectionCommand( i18n( "Remove Signal/Slot "
@@ -1,7 +1,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
-** If you wish to add, delete or rename slots use Qt Designer which will
+** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
** a constructor, and a destroy() slot in place of a destructor.